<?php
/*
Plugin Name: More Mime Type Filters
Plugin URI: http://trepmal.com
Description: Adds more options to the Media Library filter search (Images/Audio/Video)
Version: 0.2
Author: Kailey Lampert
Author URI: http://kaileylampert.com
*/

$mime_type_filters = new Mime_Type_Filters();

class Mime_Type_filters {

	function mime_type_filters() {
		add_filter('post_mime_types', array( &$this, 'add_mime_type_filters' ) );
		add_action( 'admin_menu', array( &$this, 'mime_type_menu' ) );
		self::version_check();
	}

	function add_mime_type_filters( $post_mime_types ) {

		$opts = get_option( 'mime_type_options', array() );
		//since image/audio/video are defaults, we need to explicitly remove them if they've been uncheck in the options
		if (!isset($opts['image'])) unset($post_mime_types['image']);
		if (!isset($opts['audio'])) unset($post_mime_types['audio']);
		if (!isset($opts['video'])) unset($post_mime_types['video']);
		foreach( $opts as $ext => $vs ) {
			$post_mime_types[ $vs['mime_type'] ] = array(__( $vs['singular'] ), __('Manage '. $vs['singular'] ), _n_noop( $vs['singular'] .' <span class="count">(%s)</span>', $vs['plural'] . ' <span class="count">(%s)</span>'));
		}

		return $post_mime_types;
	}

	function mime_type_menu() {
		$page = add_media_page('Mime Types', 'Mime Types', 'administrator', 'mime_type_mngr', array( &$this, 'mime_type_page' ) );
		if ($page) add_contextual_help( $page, self::mime_type_help_page() );

	}
		function mime_type_help_page() {
			return '<p>First box: Singular form of the label. Second box: Plural form.</p>
			<p>If you have selected a particular type but there are no attachments of that type, it will be ignored until such a post is added.</p>';
		}

	function mime_type_page() {
		if (isset($_POST['save-mime-options'])) {
			$mimes = $_POST['mimes'];
			$x = array(); //selected items
			$y = array(); //all, so we can preserve labels
			foreach( $mimes as $ext => $type) {
				$y[ $ext ] = array( 'singular' => $mimes[ $ext ]['singular'],
									'plural' => $mimes[ $ext ]['plural'] );
				if (isset($mimes[ $ext ]['on']))
				$x[ $ext ] = $y[ $ext ] + array( 'mime_type' => $mimes[ $ext ]['on']);
			}
			update_option( 'mime_type_options', $x );
			update_option( 'mime_type_settings', $y );
		}

		?><div class="wrap">
		<h2>Media Library Mime Types</h2>
		<form action="" method="post">
		<ul>
		<?php
			$opts = get_option( 'mime_type_options', array() );
			$sets = get_option( 'mime_type_settings' , array() );

			$mimes = get_allowed_mime_types();
			//the default generics (image/audio/video) aren't in get_allowed_mime_types()
			//so we merge them here for ease
			$mimes = array_merge( array('image' => 'image', 'audio' => 'audio', 'video' => 'video'), $mimes );

			foreach( $mimes as $ext => $mime ) {
				$type = explode('/',$mime);
				$type = isset($type['1']) ? $type['1'] : $type['0'];
				?><li>
				<label for="mime_<?php echo $ext; ?>"><input type="checkbox" name="mimes[<?php echo $ext; ?>][on]" id="mime_<?php echo $ext; ?>" value="<?php echo $mime; ?>" <?php checked( is_array($opts[ $ext ]) ); ?>/> <?php echo $ext; ?></label>
				<label for="mime_singular_<?php echo $ext; ?>"><input type="text" name="mimes[<?php echo $ext; ?>][singular]" id="mime_singular_<?php echo $ext; ?>" value="<?php echo isset($sets[ $ext ]) ? $sets[ $ext ]['singular'] : $type; ?>" /></label>
				<label for="mime_plural_<?php echo $ext; ?>"><input type="text" name="mimes[<?php echo $ext; ?>][plural]" id="mime_plural_<?php echo $ext; ?>" value="<?php echo isset($sets[ $ext ]) ? $sets[ $ext ]['plural'] : $type.'s'; ?>" /></label>
				</li><?php
			}
		?>
		</ul>
		<input type="hidden" name="save-mime-options" value="Save" />
		<input type="submit" class="button-primary" value="Save" />
		</form>

		</div><?php
	}

	function version_check() {
		$now = '0.1';
		$was = get_option( 'more_mime_type_filters_version', '0' );

		if ( $was < $now ) {
			//'options' is where we save the items we want 'on'
			$opts = add_option( 'mime_type_options', array( 'image' => array( 'mime_type' => 'image', 'singular' => 'Image', 'plural' => 'Images'),
															'audio' => array( 'mime_type' => 'audio', 'singular' => 'Audio', 'plural' => 'Audio'),
															 'video' => array( 'mime_type' => 'video', 'singular' => 'Video', 'plural' => 'Videos'),
															 ),
								'', 'no'
								);
			//'settings' is where we save the labels for all the items
			$sets = add_option( 'mime_type_settings' , array( 'image' => array( 'singular' => 'Image', 'plural' => 'Images'),
															'audio' => array( 'singular' => 'Audio', 'plural' => 'Audio'),
															 'video' => array( 'singular' => 'Video', 'plural' => 'Videos'),
															 ),
								'', 'no'
								);
		}
		update_option( 'more_mime_type_filters_version', $now );
	}

}